@@ -6,10 +6,9 @@ from .utils import split_pks
 
 
 class TreeNodeForm(forms.ModelForm):
-
     def __init__(self, *args, **kwargs):
         super(TreeNodeForm, self).__init__(*args, **kwargs)
-        if 'tn_parent' not in self.fields:
+        if "tn_parent" not in self.fields:
             return
         exclude_pks = []
         obj = self.instance
@@ -17,5 +16,6 @@ class TreeNodeForm(forms.ModelForm):
             exclude_pks += [obj.pk]
             exclude_pks += split_pks(obj.tn_descendants_pks)
         manager = obj.__class__.objects
-        self.fields['tn_parent'].queryset = manager.prefetch_related(
-            'tn_children').exclude(pk__in=exclude_pks)
+        self.fields["tn_parent"].queryset = manager.prefetch_related(
+            "tn_children"
+        ).exclude(pk__in=exclude_pks)
